# python-openimu

## install all dependencies
python 2.7
```
pip install -r requirements-2.x.txt
```

python 3
```
pip install -r requirements.txt
```

## pack to pip package
```
python ./setup.py sdist
```

## build a executor
```
pyinstaller webserver.spec
```
